/**
 * Created by MeePwn
 * https://github.com/maybewaityou
 *
 * description:
 * 屏幕工具类 以及一些常用的工具类封装
 * UI 设计基准, iPhone 6 @2x
 * width: 750 px
 * height: 1334 px
 *
 */

import { ImageStyle, TextStyle, ViewStyle } from 'react-native';

export declare const screenW: number;
export declare const screenH: number;
export declare const pixelRatio: number;
// 像素密度
export declare const DEFAULT_DENSITY: number;

/**
 * 屏幕适配, 缩放 size, 默认根据宽度适配，纵向也可以使用此方法
 * 横向的尺寸直接使用此方法
 * 如：width, paddingHorizontal, paddingLeft, paddingRight, marginHorizontal, marginLeft, marginRight
 * @param size 设计图的尺寸
 * @returns {number}
 */
export declare function scaleSize(size: number): number;

/**
 * 屏幕适配, 纵向的尺寸使用此方法应该会更趋近于设计稿
 * 如：height, paddingVertical, paddingTop, paddingBottom, marginVertical, marginTop, marginBottom
 * @param size 设计图的尺寸
 * @returns {number}
 */
export declare function scaleHeight(size: number): number;

/**
 * 设置字体的 size (单位 px)
 * @param size 传入设计稿上的 px, allowFontScaling 是否根据设备文字缩放比例调整，默认不会
 * @returns {number} 返回实际 sp
 */
export declare function setSpText(size: number): number;

/**
 * 判断是否为 iPhone X
 * @returns {boolean}
 */
export declare function isIPhoneX(): boolean;

/**
 * 判断是否为 iPhone X Max
 * @returns {boolean}
 */
export declare function isIPhoneXMax(): boolean;

/**
 * 判断是否为'刘海屏' (Android 始终为 false)
 */
export declare function hasFringe(): boolean;

/**
 * 根据是否是 iPhoneX 返回不同的样式
 * @param iPhoneXStyle
 * @param iosStyle
 * @param androidStyle
 * @returns {*}
 */
export declare function ifIPhoneX(iPhoneXStyle: any, iosStyle: any, androidStyle: any): any;

export declare interface IViewStyle extends ViewStyle {
  width$?: number | string;
  height$?: number | string;
  minWidth?: number | string;
  minHeight?: number | string;
  maxWidth?: number | string;
  maxHeight?: number | string;
  margin$?: number | string;
  marginHorizontal$?: number | string;
  marginVertical$?: number | string;
  marginTop$?: number | string;
  marginLeft$?: number | string;
  marginBottom$?: number | string;
  marginRight$?: number | string;
  padding$?: number | string;
  paddingHorizontal$?: number | string;
  paddingVertical$?: number | string;
  paddingTop$?: number | string;
  paddingLeft$?: number | string;
  paddingBottom$?: number | string;
  paddingRight$?: number | string;
}

export declare interface ITextStyle extends TextStyle {
  $fontSize?: string;
  width$?: number | string;
  height$?: number | string;
  minWidth?: number | string;
  minHeight?: number | string;
  maxWidth?: number | string;
  maxHeight?: number | string;
  margin$?: number | string;
  marginHorizontal$?: number | string;
  marginVertical$?: number | string;
  marginTop$?: number | string;
  marginLeft$?: number | string;
  marginBottom$?: number | string;
  marginRight$?: number | string;
  padding$?: number | string;
  paddingHorizontal$?: number | string;
  paddingVertical$?: number | string;
  paddingTop$?: number | string;
  paddingLeft$?: number | string;
  paddingBottom$?: number | string;
  paddingRight$?: number | string;
}

export declare interface IImageStyle extends ImageStyle {
  width$?: number | string;
  height$?: number | string;
  minWidth?: number | string;
  minHeight?: number | string;
  maxWidth?: number | string;
  maxHeight?: number | string;
  margin$?: number | string;
  marginHorizontal$?: number | string;
  marginVertical$?: number | string;
  marginTop$?: number | string;
  marginLeft$?: number | string;
  marginBottom$?: number | string;
  marginRight$?: number | string;
  padding$?: number | string;
  paddingHorizontal$?: number | string;
  paddingVertical$?: number | string;
  paddingTop$?: number | string;
  paddingLeft$?: number | string;
  paddingBottom$?: number | string;
  paddingRight$?: number | string;
}
